==> ooo_dev_tools-0.14.3.tar.gz: ooo_dev_tools-0.14.3/ooodev/adapter/sheet/spreadsheet_document_settings_comp.py <==
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from ooodev.adapter.beans.property_change_implement import PropertyChangeImplement
from ooodev.adapter.beans.vetoable_change_implement import VetoableChangeImplement
from ooodev.adapter.component_base import ComponentBase


if TYPE_CHECKING:
    from com.sun.star.sheet import SpreadsheetDocumentSettings  # service


class SpreadsheetDocumentSettingsComp(ComponentBase, PropertyChangeImplement, VetoableChangeImplement):
    """
    Class for managing SpreadsheetDocumentSettings Component.
    """

    # pylint: disable=unused-argument

    def __init__(self, component: SpreadsheetDocumentSettings) -> None:
        """
        Constructor

        Args:
            component (SpreadsheetDocumentSettings): UNO SpreadsheetDocumentSettingsSettings Component
        """
        ComponentBase.__init__(self, component)
        generic_args = self._get_generic_args()
        PropertyChangeImplement.__init__(self, component=self.component, trigger_args=generic_args)
        VetoableChangeImplement.__init__(self, component=self.component, trigger_args=generic_args)

    # region Overrides
    def _get_supported_service_names(self) -> tuple[str, ...]:
        """Returns a tuple of supported service names."""
        return ("com.sun.star.sheet.SpreadsheetDocumentSettings",)

    # endregion Overrides
    # region Properties
    @property
    def component(self) -> SpreadsheetDocumentSettings:
        """SpreadsheetDocumentSettingsSettings Component"""
        return cast("SpreadsheetDocumentSettings", self._get_component())

    # endregion Properties

==> ooo_dev_tools-0.47.13.tar.gz: ooo_dev_tools-0.47.13/ooodev/adapter/sheet/spreadsheet_document_settings_comp.py <==
from __future__ import annotations
from typing import cast, TYPE_CHECKING
from ooodev.adapter.beans.property_change_implement import PropertyChangeImplement
from ooodev.adapter.beans.vetoable_change_implement import VetoableChangeImplement
from ooodev.adapter.component_base import ComponentBase


if TYPE_CHECKING:
    from com.sun.star.sheet import SpreadsheetDocumentSettings  # service


class SpreadsheetDocumentSettingsComp(ComponentBase, PropertyChangeImplement, VetoableChangeImplement):
    """
    Class for managing SpreadsheetDocumentSettings Component.
    """

    # pylint: disable=unused-argument

    def __init__(self, component: SpreadsheetDocumentSettings) -> None:
        """
        Constructor

        Args:
            component (SpreadsheetDocumentSettings): UNO SpreadsheetDocumentSettingsSettings Component
        """
        ComponentBase.__init__(self, component)
        # pylint: disable=no-member
        generic_args = self._ComponentBase__get_generic_args()  # type: ignore
        PropertyChangeImplement.__init__(self, component=self.component, trigger_args=generic_args)
        VetoableChangeImplement.__init__(self, component=self.component, trigger_args=generic_args)

    # region Overrides
    def _ComponentBase__get_supported_service_names(self) -> tuple[str, ...]:
        """Returns a tuple of supported service names."""
        return ("com.sun.star.sheet.SpreadsheetDocumentSettings",)

    # endregion Overrides
    # region Properties
    @property
    def component(self) -> SpreadsheetDocumentSettings:
        """SpreadsheetDocumentSettingsSettings Component"""
        # pylint: disable=no-member
        return cast("SpreadsheetDocumentSettings", self._ComponentBase__get_component())  # type: ignore

    # endregion Properties
